require "inifile"
require_relative "errors"

class ConfigLoader
  ARN_CONFIG_FILE_PATH = ".aws/config".freeze

  def self.build
    config_file = File.join(ENV["HOME"], ARN_CONFIG_FILE_PATH)

    raise AwsMfa::Errors::ConfigurationNotFound, "Configuration not found." unless File.readable?(config_file)

    new(config_file)
  end

  def initialize(config_file)
    @config_file = config_file
  end

  def load
    config = IniFile.load(@config_file).to_h
    config.each_with_object({}) do |(key, value), acc|
      key =
        if key.start_with?("profile ")
          key.gsub("profile ", "")
        else
          key
        end

      acc[key] = value
    end
  end
end
