class CredentialsOutputExecutor
  def execute_output(execution_output, credentials)
    case execution_output
    when :set_env
      unset_environment
      export_credentials(credentials)
    when :quiet
      nil
    when :set_env_and_execute
      unset_environment
      export_credentials(credentials)
      execute_command_line_arguments
    when :print_env
      print_credentials(credentials)
    end
  end

  private

  def unset_environment
    ENV.delete('AWS_SECRET_ACCESS_KEY')
    ENV.delete('AWS_ACCESS_KEY_ID')
    ENV.delete('AWS_SESSION_TOKEN')
  end

  def export_credentials(credentials)
    ENV['AWS_SECRET_ACCESS_KEY'] = credentials['SecretAccessKey']
    ENV['AWS_ACCESS_KEY_ID'] = credentials['AccessKeyId']
    ENV['AWS_SESSION_TOKEN'] = credentials['SessionToken']
  end

  def print_credentials(credentials)
    puts "export AWS_SECRET_ACCESS_KEY='#{credentials['SecretAccessKey']}'"
    puts "export AWS_ACCESS_KEY_ID='#{credentials['AccessKeyId']}'"
    puts "export AWS_SESSION_TOKEN='#{credentials['SessionToken']}'"
  end

  def execute_command_line_arguments
    exec(*ARGV)
  end
end
